Case History

## Itanagar Bench

## Case Details

Case Type : BA
Filing Number: 343/2024Filing Date: 24-06-2024
Registration Number: 64/2024 Registration Date: 24-06-2024
CNR Number: GAHC04-000792-2024

## Case Status

First Hearing Date :
Next Hearing Date: Next Date is not given
Stage of Case: MOTION
Coram : 1366HONBLE MR. JUSTICE PARTHIVJYOTI SAIKIA Bench : Single Bench State : Arunachal Pradesh Judicial : Criminal Section Not Before Me :

## Petitioner and Advocate

1) Mama Rigam
Advocate- Teto Taba,Begi Taba,Begi Taba ,Begi Taba,C Ering,Vijay Duku Raji,Mardo Game,Anong kabak,Nimcha Hondique

## Respondent and Advocate

1) The State of AP and Anr
Advocate - P P of AP
2) Miss Tana Moryom

## Subordinate Court Information

Court Number and Name: ---
Case Number and Year: 0
Case Decision Date : : --state:
District:

## History of Case Hearing

Cause List Type | Judge | Business On Date | Hearing Date | Purpose of hearing
--- | --- | --- | --- | ---
Supplementary | HONBLE MR. JUSTICE BUDI HABUNG | 25-06-2024 |  | MOTION

## Orders

Order Number | Order on | Judge | Order Date | Order Details
1 | BA/64/2024 | HONBLE MR. JUSTICE BUDI HABUNG | 25-06-2024 | View

## OBJECTION

Sr.No. | Scrutiny Date | OBJECTION | Compliance Date | Receipt Date
1 | 24-06-2024 | All Objections are Complied | -- | --